
# Botbuilder offline

[![Generic badge](https://img.shields.io/badge/python-3.8%20%7C%203.9-blue)](https://www.python.org/downloads/release/python-380/)
![Travis-CI](https://www.travis-ci.com/Joffreybvn/botbuilder-offline.svg)